from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class ElectricSusceptanceUnits(Enum):
        """
            ElectricSusceptanceUnits enumeration
        """
        
        Siemens = 'Siemens'
        """
            
        """
        
        Mho = 'Mho'
        """
            
        """
        
        Nanosiemens = 'Nanosiemens'
        """
            
        """
        
        Microsiemens = 'Microsiemens'
        """
            
        """
        
        Millisiemens = 'Millisiemens'
        """
            
        """
        
        Kilosiemens = 'Kilosiemens'
        """
            
        """
        
        Megasiemens = 'Megasiemens'
        """
            
        """
        
        Gigasiemens = 'Gigasiemens'
        """
            
        """
        
        Terasiemens = 'Terasiemens'
        """
            
        """
        
        Nanomho = 'Nanomho'
        """
            
        """
        
        Micromho = 'Micromho'
        """
            
        """
        
        Millimho = 'Millimho'
        """
            
        """
        
        Kilomho = 'Kilomho'
        """
            
        """
        
        Megamho = 'Megamho'
        """
            
        """
        
        Gigamho = 'Gigamho'
        """
            
        """
        
        Teramho = 'Teramho'
        """
            
        """
        

class ElectricSusceptanceDto:
    """
    A DTO representation of a ElectricSusceptance

    Attributes:
        value (float): The value of the ElectricSusceptance.
        unit (ElectricSusceptanceUnits): The specific unit that the ElectricSusceptance value is representing.
    """

    def __init__(self, value: float, unit: ElectricSusceptanceUnits):
        """
        Create a new DTO representation of a ElectricSusceptance

        Parameters:
            value (float): The value of the ElectricSusceptance.
            unit (ElectricSusceptanceUnits): The specific unit that the ElectricSusceptance value is representing.
        """
        self.value: float = value
        """
        The value of the ElectricSusceptance
        """
        self.unit: ElectricSusceptanceUnits = unit
        """
        The specific unit that the ElectricSusceptance value is representing
        """

    def to_json(self):
        """
        Get a ElectricSusceptance DTO JSON object representing the current unit.

        :return: JSON object represents ElectricSusceptance DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Siemens"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of ElectricSusceptance DTO from a json representation.

        :param data: The ElectricSusceptance DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Siemens"}
        :return: A new instance of ElectricSusceptanceDto.
        :rtype: ElectricSusceptanceDto
        """
        return ElectricSusceptanceDto(value=data["value"], unit=ElectricSusceptanceUnits(data["unit"]))


class ElectricSusceptance(AbstractMeasure):
    """
    Electrical susceptance is the imaginary part of admittance, where the real part is conductance.

    Args:
        value (float): The value.
        from_unit (ElectricSusceptanceUnits): The ElectricSusceptance unit to create from, The default unit is Siemens
    """
    def __init__(self, value: float, from_unit: ElectricSusceptanceUnits = ElectricSusceptanceUnits.Siemens):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__siemens = None
        
        self.__mhos = None
        
        self.__nanosiemens = None
        
        self.__microsiemens = None
        
        self.__millisiemens = None
        
        self.__kilosiemens = None
        
        self.__megasiemens = None
        
        self.__gigasiemens = None
        
        self.__terasiemens = None
        
        self.__nanomhos = None
        
        self.__micromhos = None
        
        self.__millimhos = None
        
        self.__kilomhos = None
        
        self.__megamhos = None
        
        self.__gigamhos = None
        
        self.__teramhos = None
        

    def convert(self, unit: ElectricSusceptanceUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: ElectricSusceptanceUnits = ElectricSusceptanceUnits.Siemens) -> ElectricSusceptanceDto:
        """
        Get a new instance of ElectricSusceptance DTO representing the current unit.

        :param hold_in_unit: The specific ElectricSusceptance unit to store the ElectricSusceptance value in the DTO representation.
        :type hold_in_unit: ElectricSusceptanceUnits
        :return: A new instance of ElectricSusceptanceDto.
        :rtype: ElectricSusceptanceDto
        """
        return ElectricSusceptanceDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: ElectricSusceptanceUnits = ElectricSusceptanceUnits.Siemens):
        """
        Get a ElectricSusceptance DTO JSON object representing the current unit.

        :param hold_in_unit: The specific ElectricSusceptance unit to store the ElectricSusceptance value in the DTO representation.
        :type hold_in_unit: ElectricSusceptanceUnits
        :return: JSON object represents ElectricSusceptance DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Siemens"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(electric_susceptance_dto: ElectricSusceptanceDto):
        """
        Obtain a new instance of ElectricSusceptance from a DTO unit object.

        :param electric_susceptance_dto: The ElectricSusceptance DTO representation.
        :type electric_susceptance_dto: ElectricSusceptanceDto
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(electric_susceptance_dto.value, electric_susceptance_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of ElectricSusceptance from a DTO unit json representation.

        :param data: The ElectricSusceptance DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Siemens"}
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance.from_dto(ElectricSusceptanceDto.from_json(data))

    def __convert_from_base(self, from_unit: ElectricSusceptanceUnits) -> float:
        value = self._value
        
        if from_unit == ElectricSusceptanceUnits.Siemens:
            return (value)
        
        if from_unit == ElectricSusceptanceUnits.Mho:
            return (value)
        
        if from_unit == ElectricSusceptanceUnits.Nanosiemens:
            return ((value) / 1e-09)
        
        if from_unit == ElectricSusceptanceUnits.Microsiemens:
            return ((value) / 1e-06)
        
        if from_unit == ElectricSusceptanceUnits.Millisiemens:
            return ((value) / 0.001)
        
        if from_unit == ElectricSusceptanceUnits.Kilosiemens:
            return ((value) / 1000.0)
        
        if from_unit == ElectricSusceptanceUnits.Megasiemens:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricSusceptanceUnits.Gigasiemens:
            return ((value) / 1000000000.0)
        
        if from_unit == ElectricSusceptanceUnits.Terasiemens:
            return ((value) / 1000000000000.0)
        
        if from_unit == ElectricSusceptanceUnits.Nanomho:
            return ((value) / 1e-09)
        
        if from_unit == ElectricSusceptanceUnits.Micromho:
            return ((value) / 1e-06)
        
        if from_unit == ElectricSusceptanceUnits.Millimho:
            return ((value) / 0.001)
        
        if from_unit == ElectricSusceptanceUnits.Kilomho:
            return ((value) / 1000.0)
        
        if from_unit == ElectricSusceptanceUnits.Megamho:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricSusceptanceUnits.Gigamho:
            return ((value) / 1000000000.0)
        
        if from_unit == ElectricSusceptanceUnits.Teramho:
            return ((value) / 1000000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricSusceptanceUnits) -> float:
        
        if to_unit == ElectricSusceptanceUnits.Siemens:
            return (value)
        
        if to_unit == ElectricSusceptanceUnits.Mho:
            return (value)
        
        if to_unit == ElectricSusceptanceUnits.Nanosiemens:
            return ((value) * 1e-09)
        
        if to_unit == ElectricSusceptanceUnits.Microsiemens:
            return ((value) * 1e-06)
        
        if to_unit == ElectricSusceptanceUnits.Millisiemens:
            return ((value) * 0.001)
        
        if to_unit == ElectricSusceptanceUnits.Kilosiemens:
            return ((value) * 1000.0)
        
        if to_unit == ElectricSusceptanceUnits.Megasiemens:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricSusceptanceUnits.Gigasiemens:
            return ((value) * 1000000000.0)
        
        if to_unit == ElectricSusceptanceUnits.Terasiemens:
            return ((value) * 1000000000000.0)
        
        if to_unit == ElectricSusceptanceUnits.Nanomho:
            return ((value) * 1e-09)
        
        if to_unit == ElectricSusceptanceUnits.Micromho:
            return ((value) * 1e-06)
        
        if to_unit == ElectricSusceptanceUnits.Millimho:
            return ((value) * 0.001)
        
        if to_unit == ElectricSusceptanceUnits.Kilomho:
            return ((value) * 1000.0)
        
        if to_unit == ElectricSusceptanceUnits.Megamho:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricSusceptanceUnits.Gigamho:
            return ((value) * 1000000000.0)
        
        if to_unit == ElectricSusceptanceUnits.Teramho:
            return ((value) * 1000000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_siemens(siemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in siemens.

        

        :param meters: The ElectricSusceptance value in siemens.
        :type siemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(siemens, ElectricSusceptanceUnits.Siemens)

    
    @staticmethod
    def from_mhos(mhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in mhos.

        

        :param meters: The ElectricSusceptance value in mhos.
        :type mhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(mhos, ElectricSusceptanceUnits.Mho)

    
    @staticmethod
    def from_nanosiemens(nanosiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in nanosiemens.

        

        :param meters: The ElectricSusceptance value in nanosiemens.
        :type nanosiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(nanosiemens, ElectricSusceptanceUnits.Nanosiemens)

    
    @staticmethod
    def from_microsiemens(microsiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in microsiemens.

        

        :param meters: The ElectricSusceptance value in microsiemens.
        :type microsiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(microsiemens, ElectricSusceptanceUnits.Microsiemens)

    
    @staticmethod
    def from_millisiemens(millisiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in millisiemens.

        

        :param meters: The ElectricSusceptance value in millisiemens.
        :type millisiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(millisiemens, ElectricSusceptanceUnits.Millisiemens)

    
    @staticmethod
    def from_kilosiemens(kilosiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in kilosiemens.

        

        :param meters: The ElectricSusceptance value in kilosiemens.
        :type kilosiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(kilosiemens, ElectricSusceptanceUnits.Kilosiemens)

    
    @staticmethod
    def from_megasiemens(megasiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in megasiemens.

        

        :param meters: The ElectricSusceptance value in megasiemens.
        :type megasiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(megasiemens, ElectricSusceptanceUnits.Megasiemens)

    
    @staticmethod
    def from_gigasiemens(gigasiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in gigasiemens.

        

        :param meters: The ElectricSusceptance value in gigasiemens.
        :type gigasiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(gigasiemens, ElectricSusceptanceUnits.Gigasiemens)

    
    @staticmethod
    def from_terasiemens(terasiemens: float):
        """
        Create a new instance of ElectricSusceptance from a value in terasiemens.

        

        :param meters: The ElectricSusceptance value in terasiemens.
        :type terasiemens: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(terasiemens, ElectricSusceptanceUnits.Terasiemens)

    
    @staticmethod
    def from_nanomhos(nanomhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in nanomhos.

        

        :param meters: The ElectricSusceptance value in nanomhos.
        :type nanomhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(nanomhos, ElectricSusceptanceUnits.Nanomho)

    
    @staticmethod
    def from_micromhos(micromhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in micromhos.

        

        :param meters: The ElectricSusceptance value in micromhos.
        :type micromhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(micromhos, ElectricSusceptanceUnits.Micromho)

    
    @staticmethod
    def from_millimhos(millimhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in millimhos.

        

        :param meters: The ElectricSusceptance value in millimhos.
        :type millimhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(millimhos, ElectricSusceptanceUnits.Millimho)

    
    @staticmethod
    def from_kilomhos(kilomhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in kilomhos.

        

        :param meters: The ElectricSusceptance value in kilomhos.
        :type kilomhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(kilomhos, ElectricSusceptanceUnits.Kilomho)

    
    @staticmethod
    def from_megamhos(megamhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in megamhos.

        

        :param meters: The ElectricSusceptance value in megamhos.
        :type megamhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(megamhos, ElectricSusceptanceUnits.Megamho)

    
    @staticmethod
    def from_gigamhos(gigamhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in gigamhos.

        

        :param meters: The ElectricSusceptance value in gigamhos.
        :type gigamhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(gigamhos, ElectricSusceptanceUnits.Gigamho)

    
    @staticmethod
    def from_teramhos(teramhos: float):
        """
        Create a new instance of ElectricSusceptance from a value in teramhos.

        

        :param meters: The ElectricSusceptance value in teramhos.
        :type teramhos: float
        :return: A new instance of ElectricSusceptance.
        :rtype: ElectricSusceptance
        """
        return ElectricSusceptance(teramhos, ElectricSusceptanceUnits.Teramho)

    
    @property
    def siemens(self) -> float:
        """
        
        """
        if self.__siemens != None:
            return self.__siemens
        self.__siemens = self.__convert_from_base(ElectricSusceptanceUnits.Siemens)
        return self.__siemens

    
    @property
    def mhos(self) -> float:
        """
        
        """
        if self.__mhos != None:
            return self.__mhos
        self.__mhos = self.__convert_from_base(ElectricSusceptanceUnits.Mho)
        return self.__mhos

    
    @property
    def nanosiemens(self) -> float:
        """
        
        """
        if self.__nanosiemens != None:
            return self.__nanosiemens
        self.__nanosiemens = self.__convert_from_base(ElectricSusceptanceUnits.Nanosiemens)
        return self.__nanosiemens

    
    @property
    def microsiemens(self) -> float:
        """
        
        """
        if self.__microsiemens != None:
            return self.__microsiemens
        self.__microsiemens = self.__convert_from_base(ElectricSusceptanceUnits.Microsiemens)
        return self.__microsiemens

    
    @property
    def millisiemens(self) -> float:
        """
        
        """
        if self.__millisiemens != None:
            return self.__millisiemens
        self.__millisiemens = self.__convert_from_base(ElectricSusceptanceUnits.Millisiemens)
        return self.__millisiemens

    
    @property
    def kilosiemens(self) -> float:
        """
        
        """
        if self.__kilosiemens != None:
            return self.__kilosiemens
        self.__kilosiemens = self.__convert_from_base(ElectricSusceptanceUnits.Kilosiemens)
        return self.__kilosiemens

    
    @property
    def megasiemens(self) -> float:
        """
        
        """
        if self.__megasiemens != None:
            return self.__megasiemens
        self.__megasiemens = self.__convert_from_base(ElectricSusceptanceUnits.Megasiemens)
        return self.__megasiemens

    
    @property
    def gigasiemens(self) -> float:
        """
        
        """
        if self.__gigasiemens != None:
            return self.__gigasiemens
        self.__gigasiemens = self.__convert_from_base(ElectricSusceptanceUnits.Gigasiemens)
        return self.__gigasiemens

    
    @property
    def terasiemens(self) -> float:
        """
        
        """
        if self.__terasiemens != None:
            return self.__terasiemens
        self.__terasiemens = self.__convert_from_base(ElectricSusceptanceUnits.Terasiemens)
        return self.__terasiemens

    
    @property
    def nanomhos(self) -> float:
        """
        
        """
        if self.__nanomhos != None:
            return self.__nanomhos
        self.__nanomhos = self.__convert_from_base(ElectricSusceptanceUnits.Nanomho)
        return self.__nanomhos

    
    @property
    def micromhos(self) -> float:
        """
        
        """
        if self.__micromhos != None:
            return self.__micromhos
        self.__micromhos = self.__convert_from_base(ElectricSusceptanceUnits.Micromho)
        return self.__micromhos

    
    @property
    def millimhos(self) -> float:
        """
        
        """
        if self.__millimhos != None:
            return self.__millimhos
        self.__millimhos = self.__convert_from_base(ElectricSusceptanceUnits.Millimho)
        return self.__millimhos

    
    @property
    def kilomhos(self) -> float:
        """
        
        """
        if self.__kilomhos != None:
            return self.__kilomhos
        self.__kilomhos = self.__convert_from_base(ElectricSusceptanceUnits.Kilomho)
        return self.__kilomhos

    
    @property
    def megamhos(self) -> float:
        """
        
        """
        if self.__megamhos != None:
            return self.__megamhos
        self.__megamhos = self.__convert_from_base(ElectricSusceptanceUnits.Megamho)
        return self.__megamhos

    
    @property
    def gigamhos(self) -> float:
        """
        
        """
        if self.__gigamhos != None:
            return self.__gigamhos
        self.__gigamhos = self.__convert_from_base(ElectricSusceptanceUnits.Gigamho)
        return self.__gigamhos

    
    @property
    def teramhos(self) -> float:
        """
        
        """
        if self.__teramhos != None:
            return self.__teramhos
        self.__teramhos = self.__convert_from_base(ElectricSusceptanceUnits.Teramho)
        return self.__teramhos

    
    def to_string(self, unit: ElectricSusceptanceUnits = ElectricSusceptanceUnits.Siemens, fractional_digits: int = None) -> str:
        """
        Format the ElectricSusceptance to a string.
        
        Note: the default format for ElectricSusceptance is Siemens.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the ElectricSusceptance. Default is 'Siemens'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == ElectricSusceptanceUnits.Siemens:
            return f"""{super()._truncate_fraction_digits(self.siemens, fractional_digits)} S"""
        
        if unit == ElectricSusceptanceUnits.Mho:
            return f"""{super()._truncate_fraction_digits(self.mhos, fractional_digits)} ℧"""
        
        if unit == ElectricSusceptanceUnits.Nanosiemens:
            return f"""{super()._truncate_fraction_digits(self.nanosiemens, fractional_digits)} nS"""
        
        if unit == ElectricSusceptanceUnits.Microsiemens:
            return f"""{super()._truncate_fraction_digits(self.microsiemens, fractional_digits)} μS"""
        
        if unit == ElectricSusceptanceUnits.Millisiemens:
            return f"""{super()._truncate_fraction_digits(self.millisiemens, fractional_digits)} mS"""
        
        if unit == ElectricSusceptanceUnits.Kilosiemens:
            return f"""{super()._truncate_fraction_digits(self.kilosiemens, fractional_digits)} kS"""
        
        if unit == ElectricSusceptanceUnits.Megasiemens:
            return f"""{super()._truncate_fraction_digits(self.megasiemens, fractional_digits)} MS"""
        
        if unit == ElectricSusceptanceUnits.Gigasiemens:
            return f"""{super()._truncate_fraction_digits(self.gigasiemens, fractional_digits)} GS"""
        
        if unit == ElectricSusceptanceUnits.Terasiemens:
            return f"""{super()._truncate_fraction_digits(self.terasiemens, fractional_digits)} TS"""
        
        if unit == ElectricSusceptanceUnits.Nanomho:
            return f"""{super()._truncate_fraction_digits(self.nanomhos, fractional_digits)} n℧"""
        
        if unit == ElectricSusceptanceUnits.Micromho:
            return f"""{super()._truncate_fraction_digits(self.micromhos, fractional_digits)} μ℧"""
        
        if unit == ElectricSusceptanceUnits.Millimho:
            return f"""{super()._truncate_fraction_digits(self.millimhos, fractional_digits)} m℧"""
        
        if unit == ElectricSusceptanceUnits.Kilomho:
            return f"""{super()._truncate_fraction_digits(self.kilomhos, fractional_digits)} k℧"""
        
        if unit == ElectricSusceptanceUnits.Megamho:
            return f"""{super()._truncate_fraction_digits(self.megamhos, fractional_digits)} M℧"""
        
        if unit == ElectricSusceptanceUnits.Gigamho:
            return f"""{super()._truncate_fraction_digits(self.gigamhos, fractional_digits)} G℧"""
        
        if unit == ElectricSusceptanceUnits.Teramho:
            return f"""{super()._truncate_fraction_digits(self.teramhos, fractional_digits)} T℧"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricSusceptanceUnits = ElectricSusceptanceUnits.Siemens) -> str:
        """
        Get ElectricSusceptance unit abbreviation.
        Note! the default abbreviation for ElectricSusceptance is Siemens.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricSusceptanceUnits.Siemens:
            return """S"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Mho:
            return """℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Nanosiemens:
            return """nS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Microsiemens:
            return """μS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Millisiemens:
            return """mS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Kilosiemens:
            return """kS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Megasiemens:
            return """MS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Gigasiemens:
            return """GS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Terasiemens:
            return """TS"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Nanomho:
            return """n℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Micromho:
            return """μ℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Millimho:
            return """m℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Kilomho:
            return """k℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Megamho:
            return """M℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Gigamho:
            return """G℧"""
        
        if unit_abbreviation == ElectricSusceptanceUnits.Teramho:
            return """T℧"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class ElectricReactivePowerUnits(Enum):
        """
            ElectricReactivePowerUnits enumeration
        """
        
        VoltampereReactive = 'VoltampereReactive'
        """
            
        """
        
        KilovoltampereReactive = 'KilovoltampereReactive'
        """
            
        """
        
        MegavoltampereReactive = 'MegavoltampereReactive'
        """
            
        """
        
        GigavoltampereReactive = 'GigavoltampereReactive'
        """
            
        """
        

class ElectricReactivePowerDto:
    """
    A DTO representation of a ElectricReactivePower

    Attributes:
        value (float): The value of the ElectricReactivePower.
        unit (ElectricReactivePowerUnits): The specific unit that the ElectricReactivePower value is representing.
    """

    def __init__(self, value: float, unit: ElectricReactivePowerUnits):
        """
        Create a new DTO representation of a ElectricReactivePower

        Parameters:
            value (float): The value of the ElectricReactivePower.
            unit (ElectricReactivePowerUnits): The specific unit that the ElectricReactivePower value is representing.
        """
        self.value: float = value
        """
        The value of the ElectricReactivePower
        """
        self.unit: ElectricReactivePowerUnits = unit
        """
        The specific unit that the ElectricReactivePower value is representing
        """

    def to_json(self):
        """
        Get a ElectricReactivePower DTO JSON object representing the current unit.

        :return: JSON object represents ElectricReactivePower DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "VoltampereReactive"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of ElectricReactivePower DTO from a json representation.

        :param data: The ElectricReactivePower DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "VoltampereReactive"}
        :return: A new instance of ElectricReactivePowerDto.
        :rtype: ElectricReactivePowerDto
        """
        return ElectricReactivePowerDto(value=data["value"], unit=ElectricReactivePowerUnits(data["unit"]))


class ElectricReactivePower(AbstractMeasure):
    """
    In electric power transmission and distribution, volt-ampere reactive (var) is a unit of measurement of reactive power. Reactive power exists in an AC circuit when the current and voltage are not in phase.

    Args:
        value (float): The value.
        from_unit (ElectricReactivePowerUnits): The ElectricReactivePower unit to create from, The default unit is VoltampereReactive
    """
    def __init__(self, value: float, from_unit: ElectricReactivePowerUnits = ElectricReactivePowerUnits.VoltampereReactive):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__voltamperes_reactive = None
        
        self.__kilovoltamperes_reactive = None
        
        self.__megavoltamperes_reactive = None
        
        self.__gigavoltamperes_reactive = None
        

    def convert(self, unit: ElectricReactivePowerUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: ElectricReactivePowerUnits = ElectricReactivePowerUnits.VoltampereReactive) -> ElectricReactivePowerDto:
        """
        Get a new instance of ElectricReactivePower DTO representing the current unit.

        :param hold_in_unit: The specific ElectricReactivePower unit to store the ElectricReactivePower value in the DTO representation.
        :type hold_in_unit: ElectricReactivePowerUnits
        :return: A new instance of ElectricReactivePowerDto.
        :rtype: ElectricReactivePowerDto
        """
        return ElectricReactivePowerDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: ElectricReactivePowerUnits = ElectricReactivePowerUnits.VoltampereReactive):
        """
        Get a ElectricReactivePower DTO JSON object representing the current unit.

        :param hold_in_unit: The specific ElectricReactivePower unit to store the ElectricReactivePower value in the DTO representation.
        :type hold_in_unit: ElectricReactivePowerUnits
        :return: JSON object represents ElectricReactivePower DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "VoltampereReactive"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(electric_reactive_power_dto: ElectricReactivePowerDto):
        """
        Obtain a new instance of ElectricReactivePower from a DTO unit object.

        :param electric_reactive_power_dto: The ElectricReactivePower DTO representation.
        :type electric_reactive_power_dto: ElectricReactivePowerDto
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower(electric_reactive_power_dto.value, electric_reactive_power_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of ElectricReactivePower from a DTO unit json representation.

        :param data: The ElectricReactivePower DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "VoltampereReactive"}
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower.from_dto(ElectricReactivePowerDto.from_json(data))

    def __convert_from_base(self, from_unit: ElectricReactivePowerUnits) -> float:
        value = self._value
        
        if from_unit == ElectricReactivePowerUnits.VoltampereReactive:
            return (value)
        
        if from_unit == ElectricReactivePowerUnits.KilovoltampereReactive:
            return ((value) / 1000.0)
        
        if from_unit == ElectricReactivePowerUnits.MegavoltampereReactive:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricReactivePowerUnits.GigavoltampereReactive:
            return ((value) / 1000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricReactivePowerUnits) -> float:
        
        if to_unit == ElectricReactivePowerUnits.VoltampereReactive:
            return (value)
        
        if to_unit == ElectricReactivePowerUnits.KilovoltampereReactive:
            return ((value) * 1000.0)
        
        if to_unit == ElectricReactivePowerUnits.MegavoltampereReactive:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricReactivePowerUnits.GigavoltampereReactive:
            return ((value) * 1000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_voltamperes_reactive(voltamperes_reactive: float):
        """
        Create a new instance of ElectricReactivePower from a value in voltamperes_reactive.

        

        :param meters: The ElectricReactivePower value in voltamperes_reactive.
        :type voltamperes_reactive: float
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower(voltamperes_reactive, ElectricReactivePowerUnits.VoltampereReactive)

    
    @staticmethod
    def from_kilovoltamperes_reactive(kilovoltamperes_reactive: float):
        """
        Create a new instance of ElectricReactivePower from a value in kilovoltamperes_reactive.

        

        :param meters: The ElectricReactivePower value in kilovoltamperes_reactive.
        :type kilovoltamperes_reactive: float
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower(kilovoltamperes_reactive, ElectricReactivePowerUnits.KilovoltampereReactive)

    
    @staticmethod
    def from_megavoltamperes_reactive(megavoltamperes_reactive: float):
        """
        Create a new instance of ElectricReactivePower from a value in megavoltamperes_reactive.

        

        :param meters: The ElectricReactivePower value in megavoltamperes_reactive.
        :type megavoltamperes_reactive: float
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower(megavoltamperes_reactive, ElectricReactivePowerUnits.MegavoltampereReactive)

    
    @staticmethod
    def from_gigavoltamperes_reactive(gigavoltamperes_reactive: float):
        """
        Create a new instance of ElectricReactivePower from a value in gigavoltamperes_reactive.

        

        :param meters: The ElectricReactivePower value in gigavoltamperes_reactive.
        :type gigavoltamperes_reactive: float
        :return: A new instance of ElectricReactivePower.
        :rtype: ElectricReactivePower
        """
        return ElectricReactivePower(gigavoltamperes_reactive, ElectricReactivePowerUnits.GigavoltampereReactive)

    
    @property
    def voltamperes_reactive(self) -> float:
        """
        
        """
        if self.__voltamperes_reactive != None:
            return self.__voltamperes_reactive
        self.__voltamperes_reactive = self.__convert_from_base(ElectricReactivePowerUnits.VoltampereReactive)
        return self.__voltamperes_reactive

    
    @property
    def kilovoltamperes_reactive(self) -> float:
        """
        
        """
        if self.__kilovoltamperes_reactive != None:
            return self.__kilovoltamperes_reactive
        self.__kilovoltamperes_reactive = self.__convert_from_base(ElectricReactivePowerUnits.KilovoltampereReactive)
        return self.__kilovoltamperes_reactive

    
    @property
    def megavoltamperes_reactive(self) -> float:
        """
        
        """
        if self.__megavoltamperes_reactive != None:
            return self.__megavoltamperes_reactive
        self.__megavoltamperes_reactive = self.__convert_from_base(ElectricReactivePowerUnits.MegavoltampereReactive)
        return self.__megavoltamperes_reactive

    
    @property
    def gigavoltamperes_reactive(self) -> float:
        """
        
        """
        if self.__gigavoltamperes_reactive != None:
            return self.__gigavoltamperes_reactive
        self.__gigavoltamperes_reactive = self.__convert_from_base(ElectricReactivePowerUnits.GigavoltampereReactive)
        return self.__gigavoltamperes_reactive

    
    def to_string(self, unit: ElectricReactivePowerUnits = ElectricReactivePowerUnits.VoltampereReactive, fractional_digits: int = None) -> str:
        """
        Format the ElectricReactivePower to a string.
        
        Note: the default format for ElectricReactivePower is VoltampereReactive.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the ElectricReactivePower. Default is 'VoltampereReactive'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == ElectricReactivePowerUnits.VoltampereReactive:
            return f"""{super()._truncate_fraction_digits(self.voltamperes_reactive, fractional_digits)} var"""
        
        if unit == ElectricReactivePowerUnits.KilovoltampereReactive:
            return f"""{super()._truncate_fraction_digits(self.kilovoltamperes_reactive, fractional_digits)} kvar"""
        
        if unit == ElectricReactivePowerUnits.MegavoltampereReactive:
            return f"""{super()._truncate_fraction_digits(self.megavoltamperes_reactive, fractional_digits)} Mvar"""
        
        if unit == ElectricReactivePowerUnits.GigavoltampereReactive:
            return f"""{super()._truncate_fraction_digits(self.gigavoltamperes_reactive, fractional_digits)} Gvar"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricReactivePowerUnits = ElectricReactivePowerUnits.VoltampereReactive) -> str:
        """
        Get ElectricReactivePower unit abbreviation.
        Note! the default abbreviation for ElectricReactivePower is VoltampereReactive.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricReactivePowerUnits.VoltampereReactive:
            return """var"""
        
        if unit_abbreviation == ElectricReactivePowerUnits.KilovoltampereReactive:
            return """kvar"""
        
        if unit_abbreviation == ElectricReactivePowerUnits.MegavoltampereReactive:
            return """Mvar"""
        
        if unit_abbreviation == ElectricReactivePowerUnits.GigavoltampereReactive:
            return """Gvar"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class ElectricCapacitanceUnits(Enum):
        """
            ElectricCapacitanceUnits enumeration
        """
        
        Farad = 'Farad'
        """
            
        """
        
        Picofarad = 'Picofarad'
        """
            
        """
        
        Nanofarad = 'Nanofarad'
        """
            
        """
        
        Microfarad = 'Microfarad'
        """
            
        """
        
        Millifarad = 'Millifarad'
        """
            
        """
        
        Kilofarad = 'Kilofarad'
        """
            
        """
        
        Megafarad = 'Megafarad'
        """
            
        """
        

class ElectricCapacitanceDto:
    """
    A DTO representation of a ElectricCapacitance

    Attributes:
        value (float): The value of the ElectricCapacitance.
        unit (ElectricCapacitanceUnits): The specific unit that the ElectricCapacitance value is representing.
    """

    def __init__(self, value: float, unit: ElectricCapacitanceUnits):
        """
        Create a new DTO representation of a ElectricCapacitance

        Parameters:
            value (float): The value of the ElectricCapacitance.
            unit (ElectricCapacitanceUnits): The specific unit that the ElectricCapacitance value is representing.
        """
        self.value: float = value
        """
        The value of the ElectricCapacitance
        """
        self.unit: ElectricCapacitanceUnits = unit
        """
        The specific unit that the ElectricCapacitance value is representing
        """

    def to_json(self):
        """
        Get a ElectricCapacitance DTO JSON object representing the current unit.

        :return: JSON object represents ElectricCapacitance DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Farad"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of ElectricCapacitance DTO from a json representation.

        :param data: The ElectricCapacitance DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Farad"}
        :return: A new instance of ElectricCapacitanceDto.
        :rtype: ElectricCapacitanceDto
        """
        return ElectricCapacitanceDto(value=data["value"], unit=ElectricCapacitanceUnits(data["unit"]))


class ElectricCapacitance(AbstractMeasure):
    """
    Capacitance is the capacity of a material object or device to store electric charge.

    Args:
        value (float): The value.
        from_unit (ElectricCapacitanceUnits): The ElectricCapacitance unit to create from, The default unit is Farad
    """
    def __init__(self, value: float, from_unit: ElectricCapacitanceUnits = ElectricCapacitanceUnits.Farad):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__farads = None
        
        self.__picofarads = None
        
        self.__nanofarads = None
        
        self.__microfarads = None
        
        self.__millifarads = None
        
        self.__kilofarads = None
        
        self.__megafarads = None
        

    def convert(self, unit: ElectricCapacitanceUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: ElectricCapacitanceUnits = ElectricCapacitanceUnits.Farad) -> ElectricCapacitanceDto:
        """
        Get a new instance of ElectricCapacitance DTO representing the current unit.

        :param hold_in_unit: The specific ElectricCapacitance unit to store the ElectricCapacitance value in the DTO representation.
        :type hold_in_unit: ElectricCapacitanceUnits
        :return: A new instance of ElectricCapacitanceDto.
        :rtype: ElectricCapacitanceDto
        """
        return ElectricCapacitanceDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: ElectricCapacitanceUnits = ElectricCapacitanceUnits.Farad):
        """
        Get a ElectricCapacitance DTO JSON object representing the current unit.

        :param hold_in_unit: The specific ElectricCapacitance unit to store the ElectricCapacitance value in the DTO representation.
        :type hold_in_unit: ElectricCapacitanceUnits
        :return: JSON object represents ElectricCapacitance DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Farad"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(electric_capacitance_dto: ElectricCapacitanceDto):
        """
        Obtain a new instance of ElectricCapacitance from a DTO unit object.

        :param electric_capacitance_dto: The ElectricCapacitance DTO representation.
        :type electric_capacitance_dto: ElectricCapacitanceDto
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(electric_capacitance_dto.value, electric_capacitance_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of ElectricCapacitance from a DTO unit json representation.

        :param data: The ElectricCapacitance DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Farad"}
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance.from_dto(ElectricCapacitanceDto.from_json(data))

    def __convert_from_base(self, from_unit: ElectricCapacitanceUnits) -> float:
        value = self._value
        
        if from_unit == ElectricCapacitanceUnits.Farad:
            return (value)
        
        if from_unit == ElectricCapacitanceUnits.Picofarad:
            return ((value) / 1e-12)
        
        if from_unit == ElectricCapacitanceUnits.Nanofarad:
            return ((value) / 1e-09)
        
        if from_unit == ElectricCapacitanceUnits.Microfarad:
            return ((value) / 1e-06)
        
        if from_unit == ElectricCapacitanceUnits.Millifarad:
            return ((value) / 0.001)
        
        if from_unit == ElectricCapacitanceUnits.Kilofarad:
            return ((value) / 1000.0)
        
        if from_unit == ElectricCapacitanceUnits.Megafarad:
            return ((value) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricCapacitanceUnits) -> float:
        
        if to_unit == ElectricCapacitanceUnits.Farad:
            return (value)
        
        if to_unit == ElectricCapacitanceUnits.Picofarad:
            return ((value) * 1e-12)
        
        if to_unit == ElectricCapacitanceUnits.Nanofarad:
            return ((value) * 1e-09)
        
        if to_unit == ElectricCapacitanceUnits.Microfarad:
            return ((value) * 1e-06)
        
        if to_unit == ElectricCapacitanceUnits.Millifarad:
            return ((value) * 0.001)
        
        if to_unit == ElectricCapacitanceUnits.Kilofarad:
            return ((value) * 1000.0)
        
        if to_unit == ElectricCapacitanceUnits.Megafarad:
            return ((value) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_farads(farads: float):
        """
        Create a new instance of ElectricCapacitance from a value in farads.

        

        :param meters: The ElectricCapacitance value in farads.
        :type farads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(farads, ElectricCapacitanceUnits.Farad)

    
    @staticmethod
    def from_picofarads(picofarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in picofarads.

        

        :param meters: The ElectricCapacitance value in picofarads.
        :type picofarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(picofarads, ElectricCapacitanceUnits.Picofarad)

    
    @staticmethod
    def from_nanofarads(nanofarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in nanofarads.

        

        :param meters: The ElectricCapacitance value in nanofarads.
        :type nanofarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(nanofarads, ElectricCapacitanceUnits.Nanofarad)

    
    @staticmethod
    def from_microfarads(microfarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in microfarads.

        

        :param meters: The ElectricCapacitance value in microfarads.
        :type microfarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(microfarads, ElectricCapacitanceUnits.Microfarad)

    
    @staticmethod
    def from_millifarads(millifarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in millifarads.

        

        :param meters: The ElectricCapacitance value in millifarads.
        :type millifarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(millifarads, ElectricCapacitanceUnits.Millifarad)

    
    @staticmethod
    def from_kilofarads(kilofarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in kilofarads.

        

        :param meters: The ElectricCapacitance value in kilofarads.
        :type kilofarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(kilofarads, ElectricCapacitanceUnits.Kilofarad)

    
    @staticmethod
    def from_megafarads(megafarads: float):
        """
        Create a new instance of ElectricCapacitance from a value in megafarads.

        

        :param meters: The ElectricCapacitance value in megafarads.
        :type megafarads: float
        :return: A new instance of ElectricCapacitance.
        :rtype: ElectricCapacitance
        """
        return ElectricCapacitance(megafarads, ElectricCapacitanceUnits.Megafarad)

    
    @property
    def farads(self) -> float:
        """
        
        """
        if self.__farads != None:
            return self.__farads
        self.__farads = self.__convert_from_base(ElectricCapacitanceUnits.Farad)
        return self.__farads

    
    @property
    def picofarads(self) -> float:
        """
        
        """
        if self.__picofarads != None:
            return self.__picofarads
        self.__picofarads = self.__convert_from_base(ElectricCapacitanceUnits.Picofarad)
        return self.__picofarads

    
    @property
    def nanofarads(self) -> float:
        """
        
        """
        if self.__nanofarads != None:
            return self.__nanofarads
        self.__nanofarads = self.__convert_from_base(ElectricCapacitanceUnits.Nanofarad)
        return self.__nanofarads

    
    @property
    def microfarads(self) -> float:
        """
        
        """
        if self.__microfarads != None:
            return self.__microfarads
        self.__microfarads = self.__convert_from_base(ElectricCapacitanceUnits.Microfarad)
        return self.__microfarads

    
    @property
    def millifarads(self) -> float:
        """
        
        """
        if self.__millifarads != None:
            return self.__millifarads
        self.__millifarads = self.__convert_from_base(ElectricCapacitanceUnits.Millifarad)
        return self.__millifarads

    
    @property
    def kilofarads(self) -> float:
        """
        
        """
        if self.__kilofarads != None:
            return self.__kilofarads
        self.__kilofarads = self.__convert_from_base(ElectricCapacitanceUnits.Kilofarad)
        return self.__kilofarads

    
    @property
    def megafarads(self) -> float:
        """
        
        """
        if self.__megafarads != None:
            return self.__megafarads
        self.__megafarads = self.__convert_from_base(ElectricCapacitanceUnits.Megafarad)
        return self.__megafarads

    
    def to_string(self, unit: ElectricCapacitanceUnits = ElectricCapacitanceUnits.Farad, fractional_digits: int = None) -> str:
        """
        Format the ElectricCapacitance to a string.
        
        Note: the default format for ElectricCapacitance is Farad.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the ElectricCapacitance. Default is 'Farad'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == ElectricCapacitanceUnits.Farad:
            return f"""{super()._truncate_fraction_digits(self.farads, fractional_digits)} F"""
        
        if unit == ElectricCapacitanceUnits.Picofarad:
            return f"""{super()._truncate_fraction_digits(self.picofarads, fractional_digits)} pF"""
        
        if unit == ElectricCapacitanceUnits.Nanofarad:
            return f"""{super()._truncate_fraction_digits(self.nanofarads, fractional_digits)} nF"""
        
        if unit == ElectricCapacitanceUnits.Microfarad:
            return f"""{super()._truncate_fraction_digits(self.microfarads, fractional_digits)} μF"""
        
        if unit == ElectricCapacitanceUnits.Millifarad:
            return f"""{super()._truncate_fraction_digits(self.millifarads, fractional_digits)} mF"""
        
        if unit == ElectricCapacitanceUnits.Kilofarad:
            return f"""{super()._truncate_fraction_digits(self.kilofarads, fractional_digits)} kF"""
        
        if unit == ElectricCapacitanceUnits.Megafarad:
            return f"""{super()._truncate_fraction_digits(self.megafarads, fractional_digits)} MF"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricCapacitanceUnits = ElectricCapacitanceUnits.Farad) -> str:
        """
        Get ElectricCapacitance unit abbreviation.
        Note! the default abbreviation for ElectricCapacitance is Farad.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricCapacitanceUnits.Farad:
            return """F"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Picofarad:
            return """pF"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Nanofarad:
            return """nF"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Microfarad:
            return """μF"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Millifarad:
            return """mF"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Kilofarad:
            return """kF"""
        
        if unit_abbreviation == ElectricCapacitanceUnits.Megafarad:
            return """MF"""
        